==> haskell-openpgp-asciiarmor-0.1.2-316-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 openpgp-asciiarmor
version:              0.1.2
visibility:           public
id:                   openpgp-asciiarmor-0.1.2-GsKkrMQ1Tp31WdBwJWdAnp
key:                  openpgp-asciiarmor-0.1.2-GsKkrMQ1Tp31WdBwJWdAnp
license:              MIT
copyright:            2012-2019 Clint Adams
maintainer:           Clint Adams <clint@debian.org>
author:               Clint Adams
homepage:             http://floss.scru.org/openpgp-asciiarmor
synopsis:             OpenPGP (RFC4880) ASCII Armor codec
description:          OpenPGP (RFC4880) ASCII Armor codec
category:             Codec, Data
abi:                  42613fc35639f1778c7ea485a9a5b2bd
exposed:              True
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types

hidden-modules:
    Data.Digest.CRC24 Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
    Codec.Encryption.OpenPGP.ASCIIArmor.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/openpgp-asciiarmor-0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/openpgp-asciiarmor-0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/openpgp-asciiarmor-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-openpgp-asciiarmor
hs-libraries:         HSopenpgp-asciiarmor-0.1.2-GsKkrMQ1Tp31WdBwJWdAnp
depends:
    attoparsec-0.14.4-C65PLyhXhiCHiJkC3KuQ9j base-4.17.2.1
    base64-bytestring-1.2.1.0-KTcFt1JBtqE6XrF8UIUkhn binary-0.8.9.1
    bytestring-0.11.5.3

haddock-interfaces:
    /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock

haddock-html:         /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openpgp-asciiarmor-0.1.2-317-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 openpgp-asciiarmor
version:              0.1.2
visibility:           public
id:                   openpgp-asciiarmor-0.1.2-8sTdDigEdcoLIsXizepOYb
key:                  openpgp-asciiarmor-0.1.2-8sTdDigEdcoLIsXizepOYb
license:              MIT
copyright:            2012-2019 Clint Adams
maintainer:           Clint Adams <clint@debian.org>
author:               Clint Adams
homepage:             http://floss.scru.org/openpgp-asciiarmor
synopsis:             OpenPGP (RFC4880) ASCII Armor codec
description:          OpenPGP (RFC4880) ASCII Armor codec
category:             Codec, Data
abi:                  744e49e34364a2cbb7afbc78bde82cc2
exposed:              True
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types

hidden-modules:
    Data.Digest.CRC24 Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
    Codec.Encryption.OpenPGP.ASCIIArmor.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/openpgp-asciiarmor-0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/openpgp-asciiarmor-0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/openpgp-asciiarmor-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-openpgp-asciiarmor
hs-libraries:         HSopenpgp-asciiarmor-0.1.2-8sTdDigEdcoLIsXizepOYb
depends:
    attoparsec-0.14.4-IxPlyKeM7RE2Q1eOkxwOEV base-4.17.2.1
    base64-bytestring-1.2.1.0-2WioaI2OOHv6enJjm95P5G binary-0.8.9.1
    bytestring-0.11.5.3

haddock-interfaces:
    /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock

haddock-html:         /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
